@@ -17,7 +17,7 @@ test_preserve_set_opts()
 	# Name we refer to ourselves by
 	typeset _Dbg_debugger_name='bashdb'
 	# The release name we are configured to run under.
-	typeset _Dbg_release='4.4-0.92'
+	typeset _Dbg_release='4.4-0.94'
 	. ${top_builddir}/bashdb-trace -L $libdir
 	assertEquals $old_opts $-
     else
@@ -29,7 +29,7 @@ test_preserve_set_opts()
     set +u
 }
 
-prefix=/usr/share
+prefix=/usr
 top_builddir=/src/external-vcs/sourceforge/bashdb
 abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
 # Make sure $abs_top_srcrdir has a trailing slash
